==> OpenViewerFX-6.6.14-sources.jar: org/jpedal/examples/viewer/commands/VisitWebsite.java <==
/*
 * ===========================================
 * Java Pdf Extraction Decoding Access Library
 * ===========================================
 *
 * Project Info:  http://www.idrsolutions.com
 * Help section for developers at http://www.idrsolutions.com/support/
 *
 * (C) Copyright 1997-2015 IDRsolutions and Contributors.
 *
 * This file is part of JPedal/JPDF2HTML5
 *
     This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA


 *
 * ---------------
 * VisitWebsite.java
 * ---------------
 */
package org.jpedal.examples.viewer.commands;

import org.jpedal.gui.GUIFactory;
import org.jpedal.utils.BrowserLauncher;
import org.jpedal.utils.Messages;

/**
 * This class is generic for both Swing and JavaFX.
 */
public class VisitWebsite {

    public static void execute(final Object[] args, final GUIFactory currentGUI) {
        if (args == null) {
            try {
               
                //
                BrowserLauncher.openURL("https://www.idrsolutions.com/open-fx/");
                /**/
                //
                
            } catch (final Exception e1) {
                currentGUI.showMessageDialog(Messages.getMessage("PdfViewer.ErrorWebsite"));
                // 
            }

        }
    }
}

==> OpenViewerFX-7.9.26-sources.jar: org/jpedal/examples/viewer/commands/VisitWebsite.java <==
/*
 * ===========================================
 * Java Pdf Extraction Decoding Access Library
 * ===========================================
 *
 * Project Info:  http://www.idrsolutions.com
 * Help section for developers at http://www.idrsolutions.com/support/
 *
 * (C) Copyright 1997-2017 IDRsolutions and Contributors.
 *
 * This file is part of JPedal/JPDF2HTML5
 *
     This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA


 *
 * ---------------
 * VisitWebsite.java
 * ---------------
 */
package org.jpedal.examples.viewer.commands;

import org.jpedal.gui.GUIFactory;
import org.jpedal.utils.BrowserLauncher;
import org.jpedal.utils.Messages;

/**
 * This class is generic for both Swing and JavaFX.
 */
public class VisitWebsite {

    public static void execute(final Object[] args, final GUIFactory currentGUI) {
        if (args == null) {
            try {
               
                BrowserLauncher.openURL(Messages.getMessage("PdfViewer.VisitWebsite"));
               
            } catch (final Exception e1) {
                currentGUI.showMessageDialog(e1.getMessage()+' '+Messages.getMessage("PdfViewer.ErrorWebsite"));
            }
        }
    }
}
